summaryrefslogtreecommitdiffstats
path: root/scd/scdaemon.h
diff options
context:
space:
mode:
authorWerner Koch <wk@gnupg.org>2003-09-02 21:06:34 +0200
committerWerner Koch <wk@gnupg.org>2003-09-02 21:06:34 +0200
commit936250aac9d87f464e8e4c5958d54e9ac405c878 (patch)
tree6ab4aa6a1eadbbd486327530236635d9f0563525 /scd/scdaemon.h
parent2003-08-26 Timo Schulz <twoaday@freakmail.de> (diff)
downloadgnupg2-936250aac9d87f464e8e4c5958d54e9ac405c878.tar.xz
gnupg2-936250aac9d87f464e8e4c5958d54e9ac405c878.zip
* configure.ac (HAVE_LIBUSB): Added a simple test for libusb.
* scdaemon.c, scdaemon.h: New option --pcsc-ccid. * ccid-driver.c, ccid-driver.h: New but far from being useful. * Makefile.am: Add above. * apdu.c: Add support for that ccid driver.
Diffstat (limited to 'scd/scdaemon.h')
-rw-r--r--scd/scdaemon.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/scd/scdaemon.h b/scd/scdaemon.h
index 3671c7394..43c3189b3 100644
--- a/scd/scdaemon.h
+++ b/scd/scdaemon.h
@@ -55,7 +55,8 @@ struct {
const char *homedir; /* configuration directory name */
const char *ctapi_driver; /* Library to access the ctAPI. */
const char *pcsc_driver; /* Library to access the PC/SC system. */
- int disable_opensc; /* Disable the sue of the OpenSC framework. */
+ int disable_opensc; /* Disable the use of the OpenSC framework. */
+ int disable_ccid; /* Disable the use of the internal CCID driver. */
} opt;